topleveltools
=============

.. automodule:: abjad.tools.topleveltools

Functions
---------

.. toctree::
   :hidden:

   attach
   detach
   graph
   inspect_
   iterate
   label
   mutate
   new
   override
   parse
   persist
   play
   select
   sequence
   set_
   show

.. autosummary::
   :nosignatures:

   attach
   detach
   graph
   inspect_
   iterate
   label
   mutate
   new
   override
   parse
   persist
   play
   select
   sequence
   set_
   show
